/*
 * HP XLFD Enhancements Utilities
 *
 * This file supports the HP XLFD Enhancements to the XLFD name, and is
 * based on the font server's fontxlfd.h file by Keith Packard of the
 * MIT X Consortium.
 *
 * Author:  Nathan Meyers, Hewlett-Packard Company
 *
 * $Header: xlfdutil.h,v 1.1 92/06/30 15:52:17 nathanm Exp $
 */

#ifndef _XLFDUTIL_H_
#define _XLFDUTIL_H_

#include <X11/Xlib.h>

/*
 * The ParseXLFD() procedure provides tools to take apart and put
 * together XLFD names utilizing the HP XLFD enhancements.  Typical uses
 * are for building font selection tools or for constructing variations
 * of existing fonts.
 *
 * The XLFDRec structure contains the various fields and subfields of
 * the XLFD name; the various options available with ParseXLFD allows a
 * client to decompose an XLFD name into its fields and subfields, and
 * to build new variations of an XLFD name with modified versions of
 * those fields.
 */

typedef struct _XLFDRec {

    /* Standard XLFD fields */

    char	*foundry;
    char	*familyName;
    char	*weightName;
    char	*slant;
    char	*setwidthName;
    char	*addStyleName;
    int		pixelSize;
    int		pointSize;
    int		resolutionX;
    int		resolutionY;
    char	*spacing;
    int		averageWidth;
    char	*charsetRegistry;
    char	*charsetEncoding;

    /* Enhanced XLFD fields */

    int		pixelSetsize;
    int		pointSetsize;
    int		horizWeight;
    int		vertWeight;
    int		slantAngle;
    Bool	mirrorX;	/* type Bool defined by <Xlib.h> */
    Bool	mirrorY;
    int		rotationAngle;
    char	*ranges;

} XLFDRec, *XLFDRecPtr;


#ifdef __STDC__
char *ParseXLFD(char *Fontname, XLFDRecPtr Record, int Option);
#else /* __STDC__ */
char *ParseXLFD();
#endif /* __STDC__ */

/* Options for ParseXLFD(): */

#define FONT_XLFD_REPLACE_NONE	0  /* Parse XLFD fields into structure */
#define FONT_XLFD_REPLACE_STAR	1  /* Parse, plus return wildcarded name */
#define FONT_XLFD_REPLACE_ZERO	2  /* Parse, plus return 0'd name */
#define FONT_XLFD_REPLACE_VALUE	3  /* Return name with new fields from struct */

#endif				/* _XLFDUTIL_H_ */
